--- loncom/interface/lonhtmlcommon.pm	2009/11/21 22:36:23	1.247
+++ loncom/interface/lonhtmlcommon.pm	2009/11/25 13:25:44	1.250
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.247 2009/11/21 22:36:23 www Exp $
+# $Id: lonhtmlcommon.pm,v 1.250 2009/11/25 13:25:44 droeschl Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1138,7 +1138,7 @@ sub crumbs {
     my $output='';
     unless ($noformat) { $output.='<br /><tt><b>'; }
     $output.='<font size="'.$size.'">'.$prefix.'/';
-    if (($env{'user.adv'}) | ($env{'user.author'})) {
+    if (($env{'user.adv'}) || ($env{'user.author'})) {
 	my $path=$prefix.'/';
 	foreach my $dir (split('/',$uri)) {
             if (! $dir) { next; }
@@ -1501,7 +1501,7 @@ returns: nothing
                 $item =~ s/<span(.*?)\/span>//;
                 $html .= "<li>$item</li>";
             }
-            $html .= '</li></ul>';
+            $html .= '</ul></li>';
             if ($category eq 'A') { $html .= "<li>$$links</li>"; }
         }
         $$links = $html.'</ul>';
@@ -1881,22 +1881,21 @@ sub course_custom_roles {
 
 # topic_bar
 #
 # Generates a div containing an (optional) numbered (static) image followed by a 
 # title with a background color defined in the corresponding CSS: LC_topic_bar
 # Inputs:
-# 1. number to display (corresponding static image should exist).
-#    img tag will be included if arg is an integer in the range 1 to 9. 
+# 1. number to display.
+#    If input for number is empty only the title will be displayed. 
 # 2. title text to display.
 # Outputs - a scalar containing html mark-up for the div.
 
 sub topic_bar {
-    my ($imgnum,$title) = @_;
-    my $imgtag;
-    if ($imgnum =~ /^[1-9]$/) {
-        $imgtag = '<img src="/res/adm/pages/bl_step'.$imgnum.'.gif"'. 
-                  ' alt="'.&mt('Step [_1]',$imgnum).'" /> ';
+    my ($num,$title) = @_;
+    my $number = '';
+    if ($num ne '') {
+        $number = '<span>'.$num.'</span>';
     }
-    return '<div class="LC_topic_bar">'.$imgtag.$title.'</div>';
+    return '<div class="LC_topic_bar">'.$number.$title.'</div>';
 }
 
 ##############################################
@@ -1881,22 +1881,21 @@ sub course_custom_roles {
 # topic_bar
 #
-# Generates a div containing an (optional) numbered (static) image followed by a 
+# Generates a div containing an (optional) number with a white background followed by a 
 # title with a background color defined in the corresponding CSS: LC_topic_bar
 # Inputs: